#include <stdio.h>
#include "foo.h"
void foo() {
  printf("Printed from " __FILE__ ".\n");
}
